# Material

The Material commands are used to define the materials in a model.

## Create materials

### In Mdb

```{eval-rst}
.. autoclass:: abaqus.Material.MaterialModel.MaterialModel
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### In Odb

```{eval-rst}
.. autoclass:: abaqus.Material.MaterialOdb.MaterialOdb
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::

```

## Assign properties to the material

```{eval-rst}
.. autoclass:: abaqus.Material.Material.Material
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::

```

## Other Classes

```{eval-rst}

.. toggle::

    .. automembers:: abaqus.Material
        :recursive:
        :exclude: MaterialModel, MaterialOdb, Material
```
